#!/usr/bin/perl 
#
#	This script encodes the text into UTF.
#
#  Kannada letters in the text need to be typed in the kannada alphabet as 
# per our convention and ***the "letters" should be seperated by space***.
# Matras are written as c[2-9]. ex: rani is written as r c2 n c3.		
# Matra 1 for with the short vowel 'a' should not be used. A consonant 
# with out a halant following it, is  impliciltely interpreted as one 
# with matra 1 following it.
# For entering the halves, all the consonants preceding the matra(if there it's not 'a') in the half,
# should contain a halant excepting the last consonant which would be a CV.
#  ex: rashtra is written as,  r c2 sh HH tt HH r.  (HH for halant as mentioned below)
# di0 to di9	stand for numbers.
#
# Map for other symbols (ascii characters) that we use in our conventional alphabet	
#  is as follows.
#
# 	space is SS
# 	Hulant is HH
# 	period is PP
#	comma  is CC
#
#	To facilitate for inputing those sounds not supported by Unicodes
# a verbatim mode is provided. Hash(#) begins the verbatim input and 
# a hash ends it. 
# The output UTF will be written in /tmp/utf


%map=("0",0x0C82,"00",0x0C83,"1",0x0C85,"2",0x0C86,"3",0x0C87,"4",0x0C88,"5",0x0C89,"6",0x0C8A,"7",0x0C8E,"8",0x0C8F,"10",0x0C90,"11",0x0C92,"12",0x0C93,"14",0x0C94,"k",0x0C95,"kh",0x0C96,"g",0x0C97,"gh",0x0C98,"gn",0x0C99,"ch",0x0C9A,"chh",0x0C9B,"j",0x0C9C,"jh",0x0C9D,"ny",0x0C9E,"tt",0x0C9F,"tth",0x0CA0,"dd",0x0CA1,"ddh",0x0CA2,"nna",0x0CA3,"t",0x0CA4,"th",0x0CA5,"d",0x0CA6,"dh",0x0CA7,"n",0x0CA8,"p",0x0CAA,"f",0x0CAB,"b",0x0CAC,"bh",0x0CAD,"m",0x0CAE,"y",0x0CAF,"r",0x0CB0,"l",0x0CB2,"ll",0x0CB3,"v",0x0CB5,"sh",0x0CB6,"s",0x0CB8,"h",0x0CB9,"c2",0x0CBE,"c3",0x0CBF,"c4",0x0CC0,"c5",0x0CC1,"c6",0x0CC2,"c7",0x0CC6,"c8",0x0CC7,"c10",0x0CC8,"c11",0x0CCA,"c12",0x0CCB,"c14",0x0CCC,"HH",0x0CCD,"SS"," ","PP","\n","CC",",","di0",0x0CE6,"di1",0x0CE7,"di2",0x0CE8,"di3",0x0CE9,"di4",0x0CEA,"di5",0x0CEB,"di6",0x0CEC,"di7",0x0CED,"di8",0x0CEE,"di9",0x0CEF);

open(OUT,">utf");

sub uencode{
	$code  = 0xE08080;
	($c)=@_;
	if( ($c eq " ") || ($c eq "\n") || ($c eq ",") ){
		print "$c is here\n";
		$retcode[0] =  $c; 	
		$retcode[1] = 1;
		}
	else{
		$databyte1 = $c >> 12; 
		$byte1 =  $databyte1 << 16;
		$code  =  $code | $byte1;

 		$databyte2 = $c >> 6;
		$databyte2 = $databyte2 & 0x003F;	
		$databyte2 = $databyte2 << 8;
		$code = $code | $databyte2;

		$databyte3 = $c & 0x003F ;
		$code = $code | $databyte3;
		
		$retcode[0] = $code;
		print "$code the unic\n";
		$retcode[1] = 0; 
		}
		return(@retcode);
	}


	while($_ = <STDIN>)
        {
	chomp;
	if(/stop/){last}
	@symbs = split " " ;
	$vf=0;
	foreach(@symbs){
		if(/#/){
			syswrite(OUT, $_); 	
			if(!$vf){ $vf=1; }	
			else{ $vf=0; }
			}
		elsif ($vf){ syswrite( OUT , $_." " ); }
		else{ 
			if(!(defined $map{$_})){die "ERROR:unknown input string $_";} 
			($cc,$asciflag )= uencode($map{$_}); 
			if($asciflag){syswrite(OUT,$cc); }
			else{	
				print "here $cc\n";
				my ($c1,$c2,$c3);
				$c1 =  $cc & (0x000000ff);
	    		$c2 = ($cc & (0x0000ff00)) >> 8;
	    		$c3 = ($cc & (0x00ff0000)) >> 16;
				$a=pack("C3",$c3,$c2,$c1);
				syswrite(OUT,$a);
				}
			}
		}
}
